C
C     Include file dsk02.inc
C
C     This include file declares parameters for DSK data type 2
C     (plate model).
C
C        Version 4.0.0 09-OCT-2009 (NJB)
C
C           Created local version of DSK descriptor size parameter
C           to remove dependency on INCLUDE file dskdsc.inc and to
C           allow delivery to NAIF CM.
C
C        Version 3.0.0 26-OCT-2006 (NJB)
C
C           Updated to remove normal, center, longest side, albedo, and
C           area keyword parameters.
C
C        Version 2.0.0 04-AUG-2006 (NJB)
C
C           Updated to support coarse voxel grid.  Area data
C           have now been removed.
C
C        Version 1.0.0 10-JUL-2006 (NJB)
C
C
C     Each type 2 DSK segment has integer, d.p., and character
C     components.  The segment layout in DAS address space is as
C     follows:
C
C
C        Integer layout:
C
C           +-----------------+
C           | NV              |  (# of vertices)
C           +-----------------+
C           | NP              |  (# of plates )
C           +-----------------+
C           | NVXTOT          |  (total number of voxels)
C           +-----------------+
C           | VGREXT          |  (voxel grid extents, 3 integers)   
C           +-----------------+
C           | CGRSCL          |  (coarse voxel grid scale, 1 integer)  
C           +-----------------+
C           | VOXNPT          |  (size of voxel-plate pointer list)
C           +-----------------+
C           | VOXNPL          |  (size of voxel-plate list)
C           +-----------------+
C           | VTXNPL          |  (size of vertex-plate list)
C           +-----------------+
C           | PLATES          |  (NP 3-tuples of vertex IDs)
C           +-----------------+
C           | VOXPTR          |  (voxel-plate pointer array)
C           +-----------------+
C           | VOXPLT          |  (voxel-plate list)
C           +-----------------+
C           | VTXPTR          |  (vertex-plate pointer array)
C           +-----------------+
C           | VTXPLT          |  (vertex-plate list)
C           +-----------------+
C           | CGRPTR          |  (coarse grid occupancy pointers)
C           +-----------------+
C
C
      INTEGER               IXNV
      PARAMETER           ( IXNV   =          1 )
      
      INTEGER               IXNP
      PARAMETER           ( IXNP   = IXNV   + 1 )

      INTEGER               IXNVXT 
      PARAMETER           ( IXNVXT = IXNP   + 1 )
      
      INTEGER               IXVGRX
      PARAMETER           ( IXVGRX = IXNVXT + 1 )

      INTEGER               IXCGSC
      PARAMETER           ( IXCGSC = IXVGRX + 3 )

      INTEGER               IXVXPS
      PARAMETER           ( IXVXPS = IXCGSC + 1 )

      INTEGER               IXVXLS
      PARAMETER           ( IXVXLS = IXVXPS + 1 )

      INTEGER               IXVTLS
      PARAMETER           ( IXVTLS = IXVXLS + 1 )

      INTEGER               IXPLAT
      PARAMETER           ( IXPLAT = IXVTLS + 1 )

C
C        D.p. layout:
C            
C           +-----------------+
C           | DSK descriptor  |  8 elements
C           +-----------------+
C           | Vertex bounds   |  6 values (min/max for each component)
C           +-----------------+
C           | Voxel origin    |  3 elements
C           +-----------------+
C           | Voxel size      |  1 element
C           +-----------------+
C           | Min radius      |  1 element
C           +-----------------+
C           | Max radius      |  1 element
C           +-----------------+
C           | Vertices        |  3*NV elements
C           +-----------------+
C           | Plate records   |  6*NV + 3*NP elements
C           +-----------------+
C
C
C           Each plate record contains the following items:
C 
C
C              +-----------------+
C              | Normal vector   |  3 elements  
C              +-----------------+
C              | Center vector   |  3 elements
C              +-----------------+
C              | Longest side    |  1 element
C              +-----------------+
C              | Plate albedo    |  1 element
C              +-----------------+
C
      INTEGER               LOCDSZ
      PARAMETER           ( LOCDSZ = 8 )

      INTEGER               IXDSCR
      PARAMETER           ( IXDSCR = 1 )
      
      INTEGER               IXVTBD
      PARAMETER           ( IXVTBD = IXDSCR + LOCDSZ )

      INTEGER               IXVXOR
      PARAMETER           ( IXVXOR = IXVTBD + 6 )

      INTEGER               IXVXSZ
      PARAMETER           ( IXVXSZ = IXVXOR + 3 )

      INTEGER               IXMINR
      PARAMETER           ( IXMINR = IXVXSZ + 1 )

      INTEGER               IXMAXR
      PARAMETER           ( IXMAXR = IXMINR + 1 )

      INTEGER               IXVERT
      PARAMETER           ( IXVERT = IXMAXR + 1 )

C
C     Indices of plate record members:
C
      INTEGER               IXNRML
      PARAMETER           ( IXNRML = 1 )

      INTEGER               IXCTR
      PARAMETER           ( IXCTR  = IXNRML + 3 )

      INTEGER               IXLSID
      PARAMETER           ( IXLSID = IXCTR  + 3 )

      INTEGER               IXALBD
      PARAMETER           ( IXALBD = IXLSID + 1 )

C
C     Plate record size:
C
      INTEGER               PLRCSZ
      PARAMETER           ( PLRCSZ = IXALBD )

C
C     Integer item keyword parameters used by fetch routines:
C
      INTEGER               KWNV
      PARAMETER           ( KWNV   = 1 )

      INTEGER               KWNP
      PARAMETER           ( KWNP   = KWNV   + 1 )
      
      INTEGER               KWNVXT
      PARAMETER           ( KWNVXT = KWNP   + 1 )

      INTEGER               KWVGRX
      PARAMETER           ( KWVGRX = KWNVXT + 1 )

      INTEGER               KWCGSC
      PARAMETER           ( KWCGSC = KWVGRX + 1 )

      INTEGER               KWVXPS
      PARAMETER           ( KWVXPS = KWCGSC + 1 )

      INTEGER               KWVXLS
      PARAMETER           ( KWVXLS = KWVXPS + 1 )

      INTEGER               KWVTLS
      PARAMETER           ( KWVTLS = KWVXLS + 1 )

      INTEGER               KWPLAT
      PARAMETER           ( KWPLAT = KWVTLS + 1 )

      INTEGER               KWVXPT
      PARAMETER           ( KWVXPT = KWPLAT + 1 )

      INTEGER               KWVXPL
      PARAMETER           ( KWVXPL = KWVXPT + 1 )

      INTEGER               KWVTPT
      PARAMETER           ( KWVTPT = KWVXPL + 1 )

      INTEGER               KWVTPL
      PARAMETER           ( KWVTPL = KWVTPT + 1 )

      INTEGER               KWCGPT
      PARAMETER           ( KWCGPT = KWVTPL + 1 )

C
C     Double precision item keyword parameters used by fetch routines:
C
      INTEGER               KWDSC
      PARAMETER           ( KWDSC  = KWCGPT + 1 )

      INTEGER               KWVTBD
      PARAMETER           ( KWVTBD = KWDSC  + 1 )

      INTEGER               KWVXOR
      PARAMETER           ( KWVXOR = KWVTBD + 1 )

      INTEGER               KWVXSZ
      PARAMETER           ( KWVXSZ = KWVXOR + 1 )

      INTEGER               KWVERT
      PARAMETER           ( KWVERT = KWVXSZ + 1 )

      INTEGER               KWMINR
      PARAMETER           ( KWMINR = KWVERT + 1 )

      INTEGER               KWMAXR
      PARAMETER           ( KWMAXR = KWMINR + 1 )

      INTEGER               KWPLRC
      PARAMETER           ( KWPLRC = KWMAXR + 1 )

C
C     End of include file dsk02.inc
C

