C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C
C     Include Section: Plate Model Maxima
C
C        pltmax.inc  Version 3/MKDSKPLT  08-OCT-2009 (NJB)
C
C           MAXVRT is set to 2000000.
C
C        pltmax.inc  Version 2  21-June-2002  (JAB)
C
C        pltmax.inc  Version 1  09-April-1997 (JAB)
C
C
C     The maximum number of bodies, vertices and
C     plates in a plate model or collective thereof are
C     provided here.
C
C     These values can be used to dimension arrays, or to
C     use as limit checks.
C
C     The value of MAXPLT is determined from MAXVRT via
C     Euler's Formula for simple polyhedra having triangular
C     faces.  It is a suggestive value only, as some plate
C     models may be used that are not simple polyhedra,
C     like spacecraft, planetary rings, etc.
C
 
C
C     MAXBOD is the maximum number of bodies the triangular
C            plate model software will support.
C
C     INTEGER               MAXBOD
C     PARAMETER           ( MAXBOD = 20           )

      INTEGER               MAXBOD
      PARAMETER           ( MAXBOD = 1            )
 
C
C     MAXVRT is the maximum number of vertices the triangular
C            plate model software will support.
C
      INTEGER               MAXVRT
      PARAMETER           ( MAXVRT = 2000000         )
 
C
C     MAXPLT is the maximum number of plates that the triangular
C            plate model software will support.
C
      INTEGER               MAXPLT
      PARAMETER           ( MAXPLT = 2*(MAXVRT - 2) )

C
C     MAXNPV is the maximum allowed number of vertices, 
C     not taking into account shared vertices. 
C
      INTEGER               MAXNPV
      PARAMETER           ( MAXNPV = 4*MAXPLT )

C
C     MAXVOX is the maximum number of voxels.
C
      INTEGER               MAXVOX
      PARAMETER           ( MAXVOX = 10000000 )

C
C     MAXCGR is the maximum size of the coarse voxel grid.
C     
      INTEGER               MAXCGR
      PARAMETER           ( MAXCGR = 100000 )

C
C     MAXEDG is the maximum allowed number of vertex or plate 
C     neighbors a vertex may have. 
C
      INTEGER               MAXEDG
      PARAMETER           ( MAXEDG = 120 )

C
C     The maximum 'Q' value for Gaskell shape models. This value
C     is always a multiple of 4.
C
      INTEGER               MAXQ
      PARAMETER           ( MAXQ = 512            )

 
 
C
C     End Include Section: Plate Model Maxima
C
