C$Procedure DSKGD ( DSK, return DSK segment descriptor  )
 
      SUBROUTINE DSKGD ( HANDLE, DLADSC, DSKDSC )
      IMPLICIT NONE
  
C$ Abstract
C
C     Return the DSK descriptor from a DSK segment identified
C     by a DAS handle and DLA descriptor.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     DAS
C     DSK
C
C$ Keywords
C
C     DAS
C     DSK
C     FILES
C
C$ Declarations

      INCLUDE 'dla.inc'
      INCLUDE 'dskdsc.inc'

      INTEGER               HANDLE
      INTEGER               DLADSC ( * )
      DOUBLE PRECISION      DSKDSC ( * )

C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle of a DSK file.  
C     DLADSC     I   DLA segment descriptor.
C     DSKDSC     O   DSK segment descriptor.
C
C$ Detailed_Input
C
C     HANDLE         is the handle of a DSK file that is open for
C                    read access.
C
C     DLADSC         is the DLA segment descriptor corresonding to
C                    a DSK segment.
C
C$ Detailed_Output
C
C     DSKDSC         is the DSK segment descriptor of the segment
C                    designated by the input handle and DLA descriptor.
C
C$ Parameters
C
C     See the INCLUDE file
C
C         dskdsc.inc
C
C$ Exceptions
C
C     1) If the size of the double precision component of the 
C        segment is smaller than that of a DSK descriptor, the
C        error SPICE(INVALIDFORMAT) is signaled.
C
C     2) DAS read errors will be diagnosed by routines in the
C        call tree of this routine.
C
C$ Files
C
C     See input argument HANDLE.
C
C$ Particulars
C
C     This is a convenience routine intended for use by low-level
C     routines that read DSK segments.
C     
C$ Examples
C
C     1) Dump the DSK descriptor of the first segment of a DSK file.
C
C
C              PROGRAM EX1
C              IMPLICIT NONE
C
C              INCLUDE 'dla.inc'
C              INCLUDE 'dskdsc.inc'
C              INCLUDE 'dsk02.inc'
C
C              INTEGER               FILSIZ
C              PARAMETER           ( FILSIZ = 255 )
C
C              CHARACTER*(FILSIZ)    DSK
C
C              DOUBLE PRECISION      DSKDSC ( DSKDSZ )
C
C              INTEGER               DLADSC ( DLADSZ )
C              INTEGER               HANDLE
C              INTEGER               I
C
C              LOGICAL               FOUND
C
C              CALL PROMPT ( 'Enter DSK name > ', DSK )
C
C              CALL DASOPR ( DSK, HANDLE )
C
C              CALL DLABFS ( HANDLE, DLADSC, FOUND )
C
C              IF ( .NOT. FOUND ) THEN
C                 CALL SETMSG ( 'DSK file # contains no segments.' )
C                 CALL ERRCH  ( '#', DSK                           )
C                 CALL SIGERR ( 'SPICE(INVALIDFORMAT)'             )
C              END IF
C
C              CALL DSKGD ( HANDLE, DLADSC, DSKDSC )
C
C              WRITE (*,*) 'DSK descriptor contents: '
C
C              DO I = 1, DSKDSZ
C                 WRITE (*,*) DSKDSC(I)
C              END DO
C
C              END
C
C
C$ Restrictions
C
C     1) This is a prototype routine.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 09-OCT-2009 (NJB)
C
C-&
 
C$ Index_Entries
C
C     return dsk segment descriptor
C
C-&
 

C
C     SPICELIB functions
C
      LOGICAL               RETURN

C
C     Local variables
C
      INTEGER               DPABAS
      INTEGER               DPCSIZ
      
      IF ( RETURN() ) THEN
         RETURN
      END IF

      CALL CHKIN ( 'DSKGD' )

C
C     Fetch the base address and size of the DP component of the
C     indicated segment.
C
      DPABAS = DLADSC ( DBSIDX )
      DPCSIZ = DLADSC ( DSZIDX )

C
C     If we don't have enough d.p. elements to hold a descriptor,
C     something's wrong.
C
      IF ( DPCSIZ .LT. DSKDSZ ) THEN

         CALL SETMSG ( 'Size of d.p. component of segment is #; '   //
     .                 'cannot extract descriptor.  This is a '     //
     .                 'file format error which may be indicative ' //
     .                 'of a corrupted file.'                       )
         CALL ERRINT ( '#', DPCSIZ                                  )
         CALL SIGERR ( 'SPICE(INVALIDFORMAT)'                       )
         CALL CHKOUT ( 'DSKGD'                                      )
         RETURN

      END IF

C
C     Extract the descriptor.
C     
      CALL DASRDD ( HANDLE, DPABAS+1, DPABAS+DSKDSZ, DSKDSC )

      CALL CHKOUT ( 'DSKGD' )
      RETURN
      END

