C$Procedure DSKW02 ( DSK, write type 2 segment )
 
      SUBROUTINE DSKW02 ( HANDLE, BODY,   MINLON, MAXLON, MINLAT,  
     .                    MAXLAT, NV,     VRTCES, 
     .                    NP,     PLATES, NORMLS, CENTRS,
     .                    LSIDES, ALBFLG, ALBDOS, NVXTOT, 
     .                    ORIGIN, VOXSIZ, VGREXT, NCGR,  
     .                    CGRPTR, VOXNPT, VOXNPL, VTXNPL,   
     .                    VOXPTR, VOXPLT, VTXPTR, VTXPLT         )
  
C$ Abstract
C
C     Write a type 2 segment to a DSK file.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     DAS
C     DSK
C
C$ Keywords
C
C     DAS
C     DSK
C     FILES
C
C$ Declarations

      IMPLICIT NONE

      INCLUDE  'dskdsc.inc'
      INCLUDE  'dsk02.inc'

      INTEGER               HANDLE
      INTEGER               BODY
      DOUBLE PRECISION      MINLON
      DOUBLE PRECISION      MAXLON
      DOUBLE PRECISION      MINLAT
      DOUBLE PRECISION      MAXLAT
      INTEGER               NV
      DOUBLE PRECISION      VRTCES ( 3, NV )
      INTEGER               NP
      INTEGER               PLATES ( 3, NP )
      DOUBLE PRECISION      NORMLS ( 3, NP )
      DOUBLE PRECISION      CENTRS ( 3, NP )
      DOUBLE PRECISION      LSIDES ( NP )
      LOGICAL               ALBFLG
      DOUBLE PRECISION      ALBDOS ( NP )
      INTEGER               NVXTOT
      DOUBLE PRECISION      ORIGIN ( 3 )
      DOUBLE PRECISION      VOXSIZ
      INTEGER               VGREXT ( 3 )
      INTEGER               NCGR
      INTEGER               CGRPTR ( NCGR )
      INTEGER               VOXNPT
      INTEGER               VOXNPL
      INTEGER               VTXNPL
      INTEGER               VOXPTR ( VOXNPT )
      INTEGER               VOXPLT ( VOXNPL )
      INTEGER               VTXPTR ( NV )
      INTEGER               VTXPLT ( VTXNPL )
      
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle assigned to the opened DSK file.
C     BODY       I   Body ID code.
C     MINLON     I   Minimum longitude of coverage in radians.
C     MAXLON     I   Maximum longitude of coverage in radians.
C     MINLAT     I   Minimum latitude of coverage in radians.
C     MAXLAT     I   Maximum latitude of coverage in radians.
C     NV         I   Number of vertices.
C     VRTCES     I   Vertices.
C     NP         I   Number of plates.
C     PLATES     I   Plates.
C     NORMLS     I   Plate normal vectors.
C     CENTRS     I   Plate centers.
C     LSIDES     I   Lengths of longest sides of plates.
C     ALBFLG     I   Albedo flag.
C     ALBDOS     I   Albedos of plates.
C     NVXTOT     I   Number of voxels in voxel grid.
C     ORIGIN     I   Coordinates of origin of voxel grid.
C     VOXSIZ     I   Voxel size in km.
C     VGREXT     I   Voxel grid extents.
C     NCGR       I   Number of voxels in coarse voxel grid.
C     CGRPTR     I   Coarse grid pointers into voxel pointer list.
C     VOXNPT     I   Number of pointers in voxel pointer list.
C     VOXNPL     I   Size of voxel plate association list.
C     VTXNPL     I   Size of vertex plate association list.
C     VOXPTR     I   Pointers into voxel plate association list.
C     VOXPLT     I   Voxel plate association list.
C     VTXPTR     I   Pointers into vertex plate association list.
C     VTXPLT     I   Voxel plate association list.
C
C$ Detailed_Input
C
C     HANDLE      is the DAS file handle associated with the file.
C                 The file must be open for write access.
C
C     BODY        is the ID code of the body whose surface 
C                 is described by the input plate model.
C                 
C     MINLON,
C     MAXLON,
C     MINLAT,
C     MAXLAT      are the bounds of longitude and latitude of
C                 the region completely covered by the current segment.
C
C                 Each segment must cover a longitude/latitude
C                 rectangle in the planetocentric coordinate system.
C   
C                 Units are radians.
C
C                 Note that the extrema of coordinates of points
C                 on the input plate set may exceed these bounds;
C                 the bounds indicate where coverage is guaranteed
C                 to exist.
C
C     NV          is the number of vertices belonging to the plate
C                 model.
C
C     VRTCES      is an array of coordinates of the vertices.
C                 The Ith vertex occupies elements (1:3,I) of
C                 this array.
C
C     NP          is the number of plates in the plate model.
C
C     PLATES      is a array representing the plates of the model.
C                 The elements of PLATES are vertex indices. The vertex
C                 indices of the Ith plate occupy elements (1:3,I) of
C                 this array.
C
C     NORMLS      is an array of normal vectors for the plates of
C                 the model. A normal vector for the Ith plate occupies
C                 elements (1:3,I) of this array.
C
C     CENTRS      is an array of center vectors for the plates of
C                 the model. A center vector for the Ith plate occupies
C                 elements (1:3,I) of this array.
C
C     LSIDES      is an array of lengths of longest sides of the plates
C                 of the model. The length of the longest side of the
C                 Ith plate occupies element I of this array.
C
C     ALBFLG      is a logical flag indicating whether albedo data are
C                 provided for this model.
C
C     ALBDOS      is an array of albedo values associated with the
C                 plates of this model. The albedo associated with the
C                 Ith plate occupies element I of this array. The
C                 contents of ALBDOS are meaningful only if ALBFLG is
C                 .TRUE.
C
C     NVXTOT      is the number of voxels in the fine voxel grid 
C                 associated with this model.
C
C     ORIGIN      is the position, in the body-fixed, body-centered
C                 reference frame associated with BODY, of the origin
C                 of the both the fine and coarse voxel grids
C                  associated with this model.
C
C     VOXSIZ      is the voxel edge length in km.
C
C     VGREXT      is an array containing the the extents of the voxel
C                 grid in the X, Y, and Z directions of the body-fixed
C                 frame. The extents are measured as voxel counts.
C
C     NCGR        is the number of voxels in the coarse voxel grid 
C                 associated with this model. Since each coarse voxel
C                 is a cube containing an integer number of fine
C                 voxels, the relative scale of coarse and fine
C                 voxels is determined by NCGR and NVXTOT.
C
C     CGRPTR      is an array of pointers associated with this
C                 model's coarse voxel grid; these pointers 
C                 map one-dimensional coarse voxel indices to 
C                 start indices in the fine voxel pointer list.
C
C     VOXNPT      is the cardinality of the fine voxel pointer list.
C
C     VOXNPL      is the cardinality of the plate list of the 
C                 fine voxel-plate mapping.
C
C     VTXNPL      is the cardinality of the plate list of the 
C                 vertex-plate mapping.
C
C     VOXPTR      is the fine voxel pointer list. For each fine voxel
C                 belonging to a non-empty coarse voxel, there is a
C                 pointer in this list that identifies the start index
C                 in VOXPLT of the list of plate indices associated
C                 with this fine voxel.
C
C                 The start index in VOXPTR of the set of pointers
C                 associated with a coarse voxel is given by the
C                 element of CGRPTR associated with that coarse voxel.
C
C                 Within a given coarse voxel, each fine voxel has an
C                 associated one-dimensional offset from the corner of
C                 the coarse voxel closest to the origin of the voxel
C                 grids. This offset gives the location in VOXPTR of
C                 the plate list pointer for the fine voxel.
C
C     VOXPLT      is the plate list of the fine voxel-plate mapping.
C
C     VTXPTR      is the vertex pointer list.
C
C     VTXPLT      is the plate list of the vertex-plate mapping.
C
C$ Detailed_Output
C
C     None. This routine operates by side effects.
C 
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If NVXTOT/NCGR is not the cube of an integer, the error
C        SPICE(INVALIDVALUE) is signaled.
C
C     2) If an error occurs while writing the segment,
C        the error will be diagnosed by routines in the call tree of
C        this routine.
C
C$ Files
C
C     See argument HANDLE.
C
C$ Particulars
C
C     This routine writes a type 2 segment to a DSK file that 
C     has been opened for write access.
C
C
C     Regarding 1-D indexing of data structures
C     =========================================
C
C        - Indices are 1-based, as in Fortran.
C
C        - One-dimensional indices of elements of three-dimensional
C          arrays are computed using leftmost index precedence,
C          as in Fortran. So the one-dimensional index N of an element
C          having three-dimensional indices ( I, J, K ), where
C          I belongs to the range [1, MAXI] and J belongs to the
C          range [1, MAXJ], is given by
C
C             N  =  (K-1)*(MAXI*MAXJ) + (J-1)*MAXI  +  I
C
C
C$ Examples
C
C     1) See usage in the program MKDSKPLT.
C     
C$ Restrictions
C
C     1) This routine is a prototype; the interface will change.
C
C     2) Support for albedo data will be deleted in the SPICELIB
C        version of the DSK system.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     N.J. Bachman    (JPL)
C
C$ Version
C
C-    SPICELIB Version 2.0.1, 09-OCT-2009 (NJB)
C
C        Header was added.
C
C-    Version 2.0.0 31-OCT-2006 (NJB)
C
C        Input arguments CGSCAL and VTXBDS were removed. 
C
C-    Version 1.0.0 27-JUN-2006 (NJB)
C-&
 
C$ Index_Entries
C
C     write a type 2 dsk segment
C
C-&
 



C
C     SPICELIB functions
C
      DOUBLE PRECISION      DPMAX
      DOUBLE PRECISION      DPMIN
      DOUBLE PRECISION      VNORM

      LOGICAL               FAILED
      LOGICAL               RETURN

C
C     Local parameters
C
      INTEGER               NBUFRC
      PARAMETER           ( NBUFRC = 100 )

      INTEGER               DBUFSZ
      PARAMETER           ( DBUFSZ = NBUFRC * PLRCSZ )

C
C     Local variables
C
      DOUBLE PRECISION      DBUFF  ( DBUFSZ )
      DOUBLE PRECISION      DESCR  ( DSKDSZ )
      DOUBLE PRECISION      MAXRAD
      DOUBLE PRECISION      MINRAD
      DOUBLE PRECISION      VTXBDS ( 2, 3 )

      INTEGER               CGS3
      INTEGER               CGSCAL
      INTEGER               I
      INTEGER               J
      INTEGER               NWRITE
      INTEGER               REMAIN
      INTEGER               START


      IF ( RETURN() ) THEN
         RETURN
      END IF

      CALL CHKIN ( 'DSKW02' )

C
C     Start a new DLA segment.
C
      CALL DLABNS ( HANDLE )

      IF ( FAILED() ) THEN
         CALL CHKOUT ( 'DSKW02' )
         RETURN
      END IF

C
C     Derive the coarse voxel grid scale from the number of voxels.
C
      CGSCAL = NINT (  DBLE( NVXTOT/NCGR )**(1.D0/3.D0)  )

C
C     Check the scale to make sure it's actually an exact value.
C
      CGS3 = CGSCAL ** 3

      IF ( NVXTOT .NE. (CGS3*NCGR) ) THEN

         CALL SETMSG ( 'Fine voxel count NVXTOT = #; coarse voxel  '
     .   //            'count NCGR = #; NCGR*(coarse voxel scale**3) '
     .   //            '= #, but should be equal to NVXTOT.  Fine '
     .   //            'voxel grid extents should be related to '
     .   //            'coarse voxel grid extents by a single '
     .   //            'integer scale factor.'                        )
         CALL ERRINT ( '#',  NVXTOT                                   )
         CALL ERRINT ( '#',  NCGR                                     )
         CALL ERRINT ( '#',  CGS3                                     )
         CALL SIGERR ( 'SPICE(INVALIDVALUE)'                          )
         CALL CHKOUT ( 'DSKW02'                                       )
         RETURN
         
      END IF


C
C     Start out by adding the integer data to the segment.
C
C     NV is the number of vertices.
C     NP is the number of plates.
C     NVXTOT is the number of voxels in the spatial index.
C
      CALL DASADI ( HANDLE, 1,      NV     )
      CALL DASADI ( HANDLE, 1,      NP     )
      CALL DASADI ( HANDLE, 1,      NVXTOT )
      CALL DASADI ( HANDLE, 3,      VGREXT )
      CALL DASADI ( HANDLE, 1,      CGSCAL )
      CALL DASADI ( HANDLE, 1,      VOXNPT )
      CALL DASADI ( HANDLE, 1,      VOXNPL )
      CALL DASADI ( HANDLE, 1,      VTXNPL )
      CALL DASADI ( HANDLE, 3*NP,   PLATES )
      CALL DASADI ( HANDLE, VOXNPT, VOXPTR )
      CALL DASADI ( HANDLE, VOXNPL, VOXPLT )
      CALL DASADI ( HANDLE, NV,     VTXPTR )
      CALL DASADI ( HANDLE, VTXNPL, VTXPLT )
      CALL DASADI ( HANDLE, NCGR,   CGRPTR )
      
C
C     Next add the d.p. data to the segment.
C
C
C     First, fill in the DSK segment descriptor.
C
      DESCR ( OBJIDX ) = BODY

C
C     Set the first flag element to indicate availability of normal
C     vectors and albedo data.
C
      IF ( ALBFLG ) THEN
         DESCR ( FL1IDX ) = FL13DT + FL1NRM + FL1ALB
      ELSE
         DESCR ( FL1IDX ) = FL13DT + FL1NRM
      END IF

      DESCR ( FL2IDX ) = 0
      DESCR ( TYPIDX ) = 2
      DESCR ( LNBIDX ) = MINLON
      DESCR ( LNEIDX ) = MAXLON
      DESCR ( LTBIDX ) = MINLAT
      DESCR ( LTEIDX ) = MAXLAT

C
C     Now write the descriptor into the segment.
C
      CALL DASADD ( HANDLE, DSKDSZ, DESCR )

C
C     Compute model radius bounds.  Start with the maximum radius.
C     This is simply the maximum norm of the vertices.
C
      MAXRAD = 0.D0

      DO I = 1, NV
         MAXRAD = MAX (  VNORM( VRTCES(1,I) ),  MAXRAD  )
      END DO

C
C     Compute vertex bounds.
C
      DO I = 1, 3
         VTXBDS(1,I) = DPMAX()
         VTXBDS(2,I) = DPMIN()
      END DO

      DO I = 1, NV

         DO J = 1, 3
            VTXBDS(1,J) = MIN ( VTXBDS(1,J), VRTCES(J,I) )
            VTXBDS(2,J) = MAX ( VTXBDS(2,J), VRTCES(J,I) )
         END DO

      END DO

C
C     Estimate the minimum radius using the norms of the plate 
C     centers and the lengths of the longest sides of the plates.
C     This gives us a reasonable lower bound for the radius; normally
C     the minimum will be slightly larger than this number.
C
      MINRAD = DPMAX()

      DO I = 1, NP
         MINRAD = MIN (  VNORM( CENTRS(1,I) ) - LSIDES(I),  MINRAD  )
      END DO

      MINRAD = MAX ( MINRAD, 0.D0 )


C
C     Continue with the plate data.  Also add the voxel grid origin.
C
      CALL DASADD ( HANDLE, 6,      VTXBDS )
      CALL DASADD ( HANDLE, 3,      ORIGIN )
      CALL DASADD ( HANDLE, 1,      VOXSIZ )
      CALL DASADD ( HANDLE, 1,      MINRAD )
      CALL DASADD ( HANDLE, 1,      MAXRAD )
      CALL DASADD ( HANDLE, 3*NV,   VRTCES )

C
C     Now we write the "plate records" to the file.  Each of these
C     records contains a plate's
C
C        normal vector
C        center vector
C        area
C        length of longest side
C        albedo
C
      CALL CLEARD ( DBUFSZ, DBUFF )

      REMAIN = NP

      DO WHILE ( REMAIN .GT. 0 ) 

         NWRITE = MIN ( REMAIN, NBUFRC )
C
C        Add data for the next NWRITE plates to the buffer.
C
         START  = NP - REMAIN + 1
         J      = 1

         DO I = START, START + NWRITE - 1
C
C           Copy the data for plate I into the buffer.
C
            CALL VEQU ( NORMLS(1,I), DBUFF(J  ) )
            CALL VEQU ( CENTRS(1,I), DBUFF(J+3) )
            
            DBUFF(J+6) = LSIDES(I)

            IF ( ALBFLG ) THEN
               DBUFF(J+7) = ALBDOS(I)
            ELSE
               DBUFF(J+7) = 0.D0
            END IF

            J = J + PLRCSZ

         END DO

C
C        Write the buffer contents to the file.
C
         CALL DASADD ( HANDLE, NWRITE*PLRCSZ, DBUFF )

         REMAIN = REMAIN - NWRITE

      END DO

      
C
C     End the segment.
C
      CALL DLAENS ( HANDLE )

      CALL CHKOUT ( 'DSKW02' )
      RETURN
      END 

