C$Procedure TOGRID ( Model coordinates to voxel grid coordinates )
 
       SUBROUTINE TOGRID ( MODXYZ, VOXORI, VOXSIZ, GRDXYZ )
 
C$ Abstract
C
C     Convert plate model coordinates to voxel grid coordinates.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE VOXEL
C
C$ Declarations
 
      IMPLICIT NONE
 
      DOUBLE PRECISION      VOXSIZ
      DOUBLE PRECISION      MODXYZ  ( 3 )
      DOUBLE PRECISION      VOXORI  ( 3 )
      DOUBLE PRECISION      GRDXYZ  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     MODXYZ     I   Coordinates of point in model coordinates.
C     VOXORI     I   Origin of voxel grid in model coordinates.
C     VOXSIZ     I   Voxel size in model coordinates.
C     GRDXYZ     O   Coordinates of point in voxel grid coordinates.
C
C$ Detailed_Input
C
C     MODXYZ     Coordinates of point in model coordinates.
C     VOXORI     Origin of voxel grid in model coordinates.
C     VOXSIZ     Voxel size in model coordinates.
C
C$ Detailed_Output
C
C     GRDXYZ     Coordinates of point in voxel grid coordinates.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C   C
C   C     Some position in model coordinates, i.e. the body fixed
C   C     units and frame coordinates.
C   C
C         DOUBLE PRECISION       POS(3)
C
C               ...
C
C   C
C   C     Retrive the voxel grid geometry description.
C   C
C         CALL VOXDIM ( NVOX, VOXSIZ, VOXORI)
C
C   C
C   C     Convert the coordinate POS to voxel grid coordinates.
C   C
C         CALL TOGRID ( POS, VOXORI, VOXSIZ, POSVOX )
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 08-OCT-2009 (NJB)
C
C        Updated header.
C
C-    SPICELIB Version 1.1.0, 19-OCT-2004 (EDW)
C
C        Added Examples section, edits to comments.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     Convert plate model coordinates to voxel grid coordinates
C
C-&
 
 
      INTEGER               I
 
 

 
C
C     Convert model coordinates to voxel grid coordinates
C     via a Galilean transform.
C
      DO I = 1, 3
         GRDXYZ(I) = (MODXYZ(I) - VOXORI(I)) / VOXSIZ
      END DO

      RETURN
      END
