C$Procedure      ADDLNK ( Add a new AB cell to the linked list )
 
      SUBROUTINE ADDLNK ( AVAL, BVAL, MAXVAL, PNTRS, NCELL, CELLS )
      IMPLICIT NONE

C$ Abstract
C
C     Open and add a new AB cell to the linked-list and
C     update the A-value pointer array.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     AB linked list
C
C$ Declarations
 
      INCLUDE               'pltmax.inc'

      INTEGER               AVAL
      INTEGER               BVAL
      INTEGER               MAXVAL
      INTEGER               PNTRS  ( * )
      INTEGER               NCELL
      INTEGER               CELLS  ( 2, * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVAL       I   A-value to put in new cell.
C     BVAL       I   B-value to put in new cell.
C     PNTRS     I/O  A-value pointer array to update.
C     NCELL     I/O  Number of cells in AB cell linked-list.
C     CELL      I/O  Cell array.
C
C$ Detailed_Input
C
C     AVAL       A-value to be placed in new cell.
C
C     BVAL       Associated B-value to be placed in new cell.
C
C     PNTRS      Pointers to last cell containing a given A-value.
C                Updated on output.
C
C     NCELL      Number of cells, incremented by one on output.
C
C     CELL       Cell array, updated on output.
C
C$ Detailed_Output
C
C     PNTRS      See Detailed_Input.
C
C     NCELL      See Detailed_Input.
C
C     CELL       See Detailed_Input.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If the array index AVAL exceeds the decalared 
C        size of the PNTR array, the error SPICE(ARRAYTOOSMALL)
C        signals. Occurrence of this error results
C        from the VOXSCL setting below the needed value for
C        the data.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.1.1, 08-OCT-2009 (NJB)
C
C        Re-ordered header sections.
C
C-    SPICELIB Version 1.1.0, 11-JUN-2004 (EDW)
C
C        Added check on AVAL to ensure it's smaller
C        than the size of MAXVAL.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     AB linked list
C
C-&

C
C     SPICE functions.
C
      LOGICAL               RETURN


C
C     Standard RETURN test.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF

C
C     Checkin, then test the array index.
C
      CALL CHKIN  ( 'ADDLNK' )

      IF ( AVAL .GT. MAXVAL ) THEN
         CALL SETMSG ( 'AVAL larger than array. '//
     .                 'Index = #1. Array size = #2.')
         CALL ERRINT ( '#1', AVAL                     )
         CALL ERRINT ( '#2', MAXVAL                   )
         CALL SIGERR ( 'SPICE(ARRAYTOOSMALL)'         )
         CALL CHKOUT ( 'ADDLNK'                       )
         RETURN
      END IF

C
C     Increment the cell counter.
C
      NCELL = NCELL + 1

      IF ( NCELL .GT. MAXVAL ) THEN
         CALL SETMSG ( 'NCELL larger than array. '//
     .                 'Index = #1. Array size = #2.')
         CALL ERRINT ( '#1', NCELL                     )
         CALL ERRINT ( '#2', MAXVAL                   )
         CALL SIGERR ( 'SPICE(ARRAYTOOSMALL)'         )
         CALL CHKOUT ( 'ADDLNK'                       )
         RETURN
      END IF
 
C
C     Update the cell address of the last occurence of the A-value,
C     if any. If none, PNTRS(AVAL) has value -1.
C
      CELLS(1,NCELL) = BVAL
      CELLS(2,NCELL) = PNTRS(AVAL)

      PNTRS(AVAL)    = NCELL

      CALL CHKOUT ( 'ADDLNK' )

      RETURN
      END
