C$Procedure ID2VOX ( Voxel index to coordinates )
 
      SUBROUTINE ID2VOX ( IXYZ, NVOX, VIXYZ )
 
C$ Abstract
C
C     Given a voxel's index value, return its integral voxel
C     grid coordinates.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     voxel index
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               IXYZ
      INTEGER               NVOX   ( 3 )
      INTEGER               VIXYZ  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IXYZ       I   Voxel index.
C     NVOX       I   Dimensions of voxel grid.
C     VIXYZ      O   Integral voxel coordinates.
C
C$ Detailed_Input
C
C     IXYZ       The integer voxel index for a voxel ranging 
C                from 1 to NVOX(1)*NVOX(2)*NVOX(3). The ID
C                to coord mapping is a bijection.
C
C     NVOX       An integer 3-vector defining the span of
C                the cubic voxels for each coordinate axis. 
C
C                   NVOX(1) = NINT( X         - X         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(2) = NINT( Y         - Y         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(3) = NINT( Z         - Z         )
C                                    Vox_max     Vmin_min
C
C                Where:
C
C                      X          Y          Z
C                       Vox_max    Vox_max    Vox_max
C
C                represent the maximum values of all voxel
C                space coordinates along each axis, and:
C
C                      X          Y          Z
C                       Vox_min    Vox_min    Vox_min
C
C                represent the minimum values of all voxel
C                space coordinates along each axis. 
C
C                NINT being the FORTRAN "nearest integer" function.
C
C$ Detailed_Output
C
C     VIXYZ      Integral coordinates of the voxel; values lie in
C                the ranges (1 to NVOX(1), 1 to NVOX(2), 1 to NVPX(3)).
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof     (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.3, 08-OCT-2009 (NJB)
C
C        Re-ordered header sections.
C
C-    SPICELIB Version 1.0.2, 20-SEP-2004 (EDW)
C
C        Extended header documentation.
C
C        Subroutine renamed from GETXYZ.
C
C-    SPICELIB Version 1.0.1, 19-FEB-2000 (JAB)
C
C        Removed SAVED variables.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     voxel index to coordinates
C
C-&
 
      INTEGER               IX
      INTEGER               IY
      INTEGER               IZ
      INTEGER               NX
      INTEGER               NY
      INTEGER               IXY
      INTEGER               NXNY
 
 
C
C     Compute and save constants.
C
      NX    = NVOX(1)
      NY    = NVOX(2)
      NXNY  = NX*NY
 
      IZ  = INT ( IXYZ / NXNY )
      IXY = MOD ( IXYZ, NXNY )
 
      IF ( IXY .GT. 0 ) THEN
         IZ = IZ + 1
      ELSE
         IXY = NXNY
      END IF
 
      IY = 1 + INT ( IXY / NX )
      IX = MOD ( IXY, NX ) 
 
      IF ( IX .EQ. 0 ) THEN
         IX = NX
         IY = IY - 1
      END IF
 
      VIXYZ(1) = IX
      VIXYZ(2) = IY
      VIXYZ(3) = IZ
      

      RETURN
      END
