C$Procedure  IPACK3  ( Pack three scalar components into a vector )
 
      SUBROUTINE IPACK3 ( IX, IY, IZ, VXLST )
 
C$ Abstract
C
C     Place integers in an integer 3-vector.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     VOXEL
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               IX
      INTEGER               IY
      INTEGER               IZ
      INTEGER               VXLST    ( 3 )
 
C$ Brief_I/O
C
C    VARIABLE  I/O  DESCRIPTION
C    --------  ---  --------------------------------------------------
C     IX,
C     IY,
C     IZ        I   Scalar components of a vector.
C     VXLST     O   Equivalent vector.
C
C$ Detailed_Input
C
C     IX,
C     IY,
C     IZ        are the scalar integer components of a 3-vector.
C
C$ Detailed_Output
C
C     VXLST     is the equivalent vector, such that VXLST(1) = IX
C                                                   VXLST(2) = IY
C                                                   VXLST(3) = IZ
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C      This routine encapsulates the operations:
C
C            VXLST(1) = IX
C            VXLST(2) = IY
C            VXLST(3) = IZ
C
C      for scalar integers in the same way VPACK operates
C      on three scalar doubles.
C
C$ Examples
C
C      See: Detailed_Description.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.1.1, 08-OCT-2009 (NJB)
C
C        Re-ordered header sections.
C
C-    SPICELIB Version 1.1.0, 20-OCT-2004 (EDW)
C
C        Edits to comments and header.
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C      pack scalar integer into a vector
C
C-&

      VXLST(1) = IX
      VXLST(2) = IY
      VXLST(3) = IZ
 
      RETURN
      END
