C$Procedure VOX2ID (Return voxel index from coords)
 
      INTEGER FUNCTION VOX2ID ( VIXYZ, NVOX )
 
C$ Abstract
C
C     Given a voxel's grid coordinates and the voxel grid
C     dimensions, return the voxel's index.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     VOXEL
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NVOX   ( 3 )
      INTEGER               VIXYZ  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VIXYZ      I   Voxel's grid coordinates stored in a
C                    three-dimensional vector.
C     NVOX       I   Number of voxels in each coordinate direction.
C
C     The function returns the voxel index.
C
C$ Detailed_Input
C
C     VIXYZ      An integer 3-vector storing the voxel grid coordinates
C                for the point of interest.
C
C     NVOX       An integer 3-vector defining the span of
C                the cubic voxels for each coordinate axis. 
C
C                   NVOX(1) = NINT( X         - X         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(2) = NINT( Y         - Y         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(3) = NINT( Z         - Z         )
C                                    Vox_max     Vmin_min
C
C                Where:
C
C                      X          Y          Z
C                       Vox_max    Vox_max    Vox_max
C
C                represent the maximum values of all voxel
C                space coordinates along each axis, and:
C
C                      X          Y          Z
C                       Vox_min    Vox_min    Vox_min
C
C                represent the minimum values of all voxel
C                space coordinates along each axis. 
C
C                NINT being the FORTRAN "nearest integer" function.
C
C$ Detailed_Output
C
C     The function returns the value of the voxel index.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.1.1, 08-OCT-2009 (NJB)
C
C        Re-ordered header sections.
C
C-    SPICE Version 1.1.0, 23-SEP-2004 (EDW)
C
C        Recast equation to improve runtime performance.
C        Edited comments for clarity.
C
C        Subroutine renamed from GETXYZ.
C
C-    Plate Library Version 1.0.1, 19-FEB-2000 (JAB)
C
C        Removed SAVED variables.
C
C-    Plate Library Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     given a voxel's coordinates return the voxel index
C
C-&

C
C     Convert from voxel coordinates to voxel index. A more
C     readable form for the following function:
C
C      NX     = NVOX(1)
C      NY     = NVOX(2)
C      NXNY   = NX * NY
C      NXNY2  = NX + NXNY
C
C      VOX2ID = VIXYZ(1) + VIXYZ(2)*NX + VIXYZ(3)*NXNY - NXNY2
C
C     Expressing the function in this format improves runtime
C     performance as per Horner's Rule.
C
      VOX2ID = VIXYZ(1) + NVOX(1)*( (VIXYZ(2) + VIXYZ(3)*NVOX(2))
     .                                          - (1 + NVOX(2)) )

 
      RETURN
      END
