C$Procedure  VOXPAD  ( extend to integral voxel )
 
      DOUBLE PRECISION FUNCTION  VOXPAD ( PADINT, VAL )
  
C$ Abstract
C
C     Return the distance required in voxel grid units to extend 
C     or reduce the voxel grid by VAL from PADINT.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     VOXEL
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               PADINT
      DOUBLE PRECISION      VAL
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PADINT     I   Number of additional voxels to pad out to.
C     VAL        I   Current value.
C
C     The function returns the extension distance required
C     to widen the voxel grid the desired amount.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.1.1, 08-OCT-2009 (NJB)
C
C        Re-ordered header sections.
C
C-    SPICELIB Version 1.1.0, 30-SEP-2004 (EDW)
C
C        Initialized VOXPAD to 0.D0 to handle
C        return on error.
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     pad voxel grid with additional voxels
C
C-&

      LOGICAL               RETURN

C
C     Set VOXPAD to 0 prior to processing.
C
      VOXPAD = 0.D0

C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'VOXPAD' )

C
C     The code.
C
      IF ( PADINT .LT. 0 ) THEN
 
         IF ( VAL .LT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT )
         ELSE IF ( VAL .GT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT ) - 1.D0
         ELSE
            VOXPAD = DBLE( PADINT )
         END IF
 
      ELSE IF ( PADINT .GT. 0 ) THEN
 
         IF ( VAL .GT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT )
         ELSE IF ( VAL .LT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT ) + 1.D0
         ELSE
            VOXPAD = DBLE( PADINT )
         END IF
 
      ELSE
 
         CALL SETMSG ( 'Padding direction not given.' )
         CALL SIGERR ( 'SPICE(NOPADDINGDIR)'          )
         CALL CHKOUT ( 'VOXPAD'                       )
         RETURN
 
      END IF
 
C
C     Standard SPICELIB error handling.
C
      CALL CHKOUT ( 'VOXPAD' )
 
      RETURN
      END
