C$Procedure  VRTCOM  ( given a vertex find the plates )
 
      SUBROUTINE VRTCOM ( NP, V1, V2, V3, VCPNTR, NVC, VCLIST )
      IMPLICIT NONE

C$ Abstract
C
C     Generate an array containing the plates that belong
C     to a specific vertex.
C
C$ Disclaimer
C
C     THIS SOFTWARE AND ANY RELATED MATERIALS WERE CREATED BY THE
C     CALIFORNIA INSTITUTE OF TECHNOLOGY (CALTECH) UNDER A U.S.
C     GOVERNMENT CONTRACT WITH THE NATIONAL AERONAUTICS AND SPACE
C     ADMINISTRATION (NASA). THE SOFTWARE IS TECHNOLOGY AND SOFTWARE
C     PUBLICLY AVAILABLE UNDER U.S. EXPORT LAWS AND IS PROVIDED "AS-IS"
C     TO THE RECIPIENT WITHOUT WARRANTY OF ANY KIND, INCLUDING ANY
C     WARRANTIES OF PERFORMANCE OR MERCHANTABILITY OR FITNESS FOR A
C     PARTICULAR USE OR PURPOSE (AS SET FORTH IN UNITED STATES UCC
C     SECTIONS 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE
C     SOFTWARE AND RELATED MATERIALS, HOWEVER USED.
C
C     IN NO EVENT SHALL CALTECH, ITS JET PROPULSION LABORATORY, OR NASA
C     BE LIABLE FOR ANY DAMAGES AND/OR COSTS, INCLUDING, BUT NOT
C     LIMITED TO, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND,
C     INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
C     REGARDLESS OF WHETHER CALTECH, JPL, OR NASA BE ADVISED, HAVE
C     REASON TO KNOW, OR, IN FACT, SHALL KNOW OF THE POSSIBILITY.
C
C     RECIPIENT BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF
C     THE SOFTWARE AND ANY RELATED MATERIALS, AND AGREES TO INDEMNIFY
C     CALTECH AND NASA FOR ALL THIRD-PARTY CLAIMS RESULTING FROM THE
C     ACTIONS OF RECIPIENT IN THE USE OF THE SOFTWARE.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE VERTEX
C
C$ Declarations
 
 
      INTEGER               NP
      INTEGER               V1      ( * )
      INTEGER               V2      ( * )
      INTEGER               V3      ( * )
      INTEGER               VCPNTR  ( * )
      INTEGER               NVC
      INTEGER               VCLIST  ( * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NP         I   Number of plates.
C     V1         I   Array of first vertex ID's for each plate.
C     V2         I   Array of second vertex ID's for each plate.
C     V3         I   Array of third vertex ID's for each plate.
C     VCPNTR     O   Array of pointers, by vertex, into plate data list.
C     NVC        O   Length of the plate data list.
C     VCLIST     O   Plate data list; first element is the number of
C                    plate ID's to follow.
C
C$ Detailed_Input
C
C     NP         Number of plates.
C
C     V1         Array of first vertex ID's for each plate.
C
C     V2         Array of second vertex ID's for each plate.
C
C     V3         Array of third vertex ID's for each plate.
C
C$ Detailed_Output
C
C     VCPNTR      Array of pointers, by vertex, into plate data list.
C
C     NVC        Length of the plate data list.
C
C     VCLIST     Plate data list; first element is the number of
C                plate ID's to follow.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 08-OCT-2009 (NJB)
C
C        Re-ordered header sections.
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     given a vertex find the plates it belongs to
C
C-&
 
      INCLUDE              'pltmax.inc'

      INTEGER               MAXVAL
      PARAMETER            (MAXVAL = 3*MAXPLT )

C
C     Local variables.
C
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               NCELL
      INTEGER               PNTRS   ( MAXVAL )
      INTEGER               CELLS   ( 2, MAXVAL )
 

      SAVE

C
C     Standard SPICELIB error handling.
C
 
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'VRTCOM' )

      IF ( NP .GT. MAXPLT ) THEN
         CALL SETMSG ( 'Index larger than array. '//
     .                 'Index = #1. Array size = #2.')
         CALL ERRINT ( '#1', NP                      )
         CALL ERRINT ( '#2',  MAXPLT                 )
         CALL SIGERR ( 'SPICE(ARRAYTOOSMALL)'        )
         CALL CHKOUT (  'VRTCOM'                     )
         RETURN

      END IF
 
C
C     Initialize pointer and cell structure.
C
      CALL INILNK ( MAXVAL, MAXVAL, NCELL, PNTRS, CELLS )

C
C     Loop over all plate IDS. Add each plate/vertex 
C     combination to the linked list.
C
      DO I = 1, NP

C
C        AVAL = V1(I), vertex 1 of plate ID I. 
C        BVAL = I, plate ID value I.
C
         CALL ADDLNK ( V1(I), I, MAXVAL, PNTRS, NCELL, CELLS )

C
C        AVAL = V2(I), vertex 2 of plate ID I. Same BVAL.
C
         CALL ADDLNK ( V2(I), I, MAXVAL, PNTRS, NCELL, CELLS )

C
C        AVAL = V3(I), vertex 3 of plate ID I.  Same BVAL.
C
         CALL ADDLNK ( V3(I), I, MAXVAL, PNTRS, NCELL, CELLS )

      END DO

C
C     Generate two linked lists mapping vertex ID to the plates
C     including that vertex as a member.
C
C     VCPNTR: An array, indexed by vertex ID. For an array element, 
C             VCPNTR(VERT_ID), greater than zero, the value identifies 
C             an index in VCLIST, the value of that VCLIST array
C             elemement  equaling the number of plates that include 
C             the vertex specified by the ID as a member. The  
C             condition VCPNTR(VERT_ID) = -1 indicates a bug.
C
C     VCLIST: An array, indexed by the positive entries in VCPNTR.
C             The element, N, identified by a VCPNTR value describes
C             the number of plates of which the vertex is a member. 
C
C                 N = VCLIST( VCPNTR(VERT_ID) )
C
C             The N elements following VCLIST( VCPNTR(VERT_ID) ),
C             contain the IDs of those plates which have the vertex
C             as a member.
C
      CALL UNTNGL ( NCELL , PNTRS, MAXVAL, CELLS,
     .              VCPNTR, NVC  , VCLIST )
 
C
C     Standard SPICE error handling.
C
      CALL CHKOUT ( 'VRTCOM' )
 
      RETURN
      END
